@@ -49,15 +49,14 @@ class Provider(SsnProvider):
         """
 
         if dob:
-            birthday = datetime.datetime.strptime(dob, '%Y%m%d')
+            birthday = datetime.datetime.strptime(dob, "%Y%m%d")
         else:
-            age = datetime.timedelta(
-                days=self.generator.random.randrange(18 * 365, 90 * 365))
+            age = datetime.timedelta(days=self.generator.random.randrange(18 * 365, 90 * 365))
             birthday = datetime.datetime.now() - age
         if not gender:
-            gender = self.generator.random.choice(('F', 'M'))
-        elif gender not in ('F', 'M'):
-            raise ValueError('Gender must be one of F or M.')
+            gender = self.generator.random.choice(("F", "M"))
+        elif gender not in ("F", "M"):
+            raise ValueError("Gender must be one of F or M.")
 
         while True:
             if 1900 <= birthday.year <= 1999:
@@ -68,11 +67,11 @@ class Provider(SsnProvider):
                 suffix = str(self.generator.random.randrange(50, 99))
             elif 1940 <= birthday.year <= 1999:
                 suffix = str(self.generator.random.randrange(90, 99))
-            if gender == 'F':
+            if gender == "F":
                 gender_num = self.generator.random.choice((0, 2, 4, 6, 8))
-            elif gender == 'M':
+            elif gender == "M":
                 gender_num = self.generator.random.choice((1, 3, 5, 7, 9))
-            pnr = birthday.strftime('%d%m%y') + suffix.zfill(2) + str(gender_num)
+            pnr = birthday.strftime("%d%m%y") + suffix.zfill(2) + str(gender_num)
             pnr_nums = [int(ch) for ch in pnr]
             k1 = checksum(Provider.scale1, pnr_nums)
             k2 = checksum(Provider.scale2, pnr_nums + [k1])
@@ -80,5 +79,5 @@ class Provider(SsnProvider):
             # https://no.wikipedia.org/wiki/F%C3%B8dselsnummer
             if k1 == 10 or k2 == 10:
                 continue
-            pnr += f'{k1}{k2}'
+            pnr += f"{k1}{k2}"
             return pnr
